"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const json_schema_migrate_1 = require("json-schema-migrate");
const ajv_1 = __importDefault(require("ajv"));
const consola_1 = __importDefault(require("consola"));
const fs_1 = __importDefault(require("fs"));
const globby_1 = __importDefault(require("globby"));
const path_1 = __importDefault(require("path"));
const utilities_1 = require("./utilities");
exports.default = async ({ srcFilePath, schemaFileURL, strict = false, }) => {
    try {
        const cwd = process.cwd();
        const srcFilePaths = await globby_1.default(srcFilePath, {
            gitignore: true,
        });
        const schema = await utilities_1.getSchemaFromURL(schemaFileURL);
        json_schema_migrate_1.draft7(schema);
        const validator = new ajv_1.default({ strict, logger: false }).compile(schema);
        const results = await Promise.all(srcFilePaths.map(async (srcFilePath) => {
            const srcFileFullPath = path_1.default.resolve(cwd, srcFilePath);
            const src = await fs_1.default.promises.readFile(srcFileFullPath, 'utf-8').then((data) => {
                return JSON.parse(data);
            });
            return validator(src);
        }));
        return results.every((result) => {
            return result == true;
        });
    }
    catch (error) {
        consola_1.default.error(error);
        throw new Error(error);
    }
};
