"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSchemaFromURL = void 0;
const url_1 = require("url");
const consola_1 = __importDefault(require("consola"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const isRemote = (url) => {
    try {
        const protocol = new url_1.URL(url).protocol;
        if (protocol === 'http:' || protocol === 'https:')
            return true;
        return false;
    }
    catch {
        return false;
    }
};
const readLocalSchema = async (schemaPath) => {
    const cwd = process.cwd();
    const schemaFullPath = path_1.default.resolve(cwd, schemaPath);
    return await fs_1.default.promises
        .readFile(schemaFullPath, {
        encoding: 'utf-8',
    })
        .then((data) => {
        consola_1.default.success('Success read schema file');
        return JSON.parse(data);
    })
        .catch(() => {
        throw new Error('Faild read schema file');
    });
};
const fetchRemoteSchema = async (schemaURL) => {
    return await node_fetch_1.default(schemaURL)
        .then(async (data) => {
        consola_1.default.success('Success download schema file');
        return (await data.json());
    })
        .catch(() => {
        throw new Error('Faild download schema file');
    });
};
const getSchemaFromURL = async (schemaURL) => {
    return isRemote(schemaURL) ? await fetchRemoteSchema(schemaURL) : await readLocalSchema(schemaURL);
};
exports.getSchemaFromURL = getSchemaFromURL;
